audioc: Improve documentation of main().
[paraslash.git] / write.h
diff --git a/write.h b/write.h
index c7196dc5644614e66525b1bfa524ec346579d64d..56a9711a44af6fde00ef23f6f5d203e407daf4d0 100644 (file)
--- a/write.h
+++ b/write.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2010 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2006-2012 Andre Noll <maan@systemlinux.org>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
@@ -19,8 +19,11 @@ struct writer_node {
        void *private_data;
        /** The writer-specific configuration of this node. */
        void *conf;
+       /** The buffer tree node associated with this writer node. */
        struct btr_node *btrn;
+       /** The task of this writer node. */
        struct task task;
+       /** The minimal input queue size (size of one audio sample). */
        size_t min_iqs;
 };
 
@@ -36,21 +39,20 @@ struct writer {
        /**
         * The command line parser of the writer.
         *
* It should check whether the command line options given by \a options are
* valid.  On success, it should return a pointer to the writer-specific
* configuration data determined by \a options.  Note that this might be called
* more than once with different values of \a options.
         */
-       void *(*parse_config)(const char *options);
-       void (*free_config)(void *conf);
+       void *(*parse_config_or_die)(const char *options);
        /**
-        * Open one instance of this writer.
+        * Dellocate all configuration resources.
         *
-        * This function should perform any work necessary to write the incoming
-        * stream. To this aim, it may allocate its private data structure and store
-        * a pointer to that structure via the given writer_node parameter.
+        * This should free whatever was allocated by \ref parse_config_or_die().
         */
-       int (*open)(struct writer_node *);
+       void (*free_config)(void *config);
        /**
         * Prepare the fd sets for select.
         *
@@ -71,12 +73,19 @@ struct writer {
         */
        void (*close)(struct writer_node *);
        /**
-        * Shutdown the writer
+        * Shutdown the writer.
         *
         * This is a optional function pointer used for cleaning up.
         */
        void (*shutdown)(struct writer_node *);
+       /** The short and the log help text of this writer. */
        struct ggo_help help;
+       /**
+        * The callback handler.
+        *
+        * Each writer may provide an ->execute callback which can be used for
+        * inter-node communication.
+        */
        btr_command_handler execute;
 };
@@ -36,21 +39,20 @@ struct writer {
         * The command line parser of the writer.
         *
-        * It should check whether the command line options given by \a options are
-        * valid.  On success, it should return a pointer to the writer-specific
-        * configuration data determined by \a options.  Note that this might be called
-        * more than once with different values of \a options.
+        * It should check whether the command line options given by \a options
+        * are valid and return a pointer to the writer-specific configuration
+        * data determined by \a options. This function must either succeed or
+        * call exit(). Note that parse_config_or_die() might be called more
+        * than once with different values of \a options. \sa \ref
+        * free_config().
         */